 [HandleNumber SerialNumber] = mfcs_init;
AlphaValue = 5; % this is for the PID, according to the guys at fluigent this is already the optimal value and should not be changed

fid = fopen( 'MatlabCrashReport.txt', 'wt' );
 
% Beginning of user defined variables
% Please adjust and change these to match a steady state condition in
% Maesflo(MFCS Fluigent)
p_c = 50;               % mbar; Equilibrium pressure for Continous phase (Chann-1)
p_d = 26;               % mbar; Equilibrium pressure for dispersed phase (Chann-2)
 
deltap_d_form = 20;     % mbar; pulse strength for dispersed phase 
deltap_c_form = 3;      % mbar; pulse strength for continuous phase
deltat_form = 0.2;      % seconds; pulse duration  
deltat_pause = 16;      % seconds; Pause duration 
deltap_c_release = 12;  % mbar; release pressure strength for continous phase
deltap_d_release = 5;   % mbar; release pressure strength for dispersed phase
deltat_release = 5;     % seconds; duration of release/ transport of droplet 
deltat_cycle = 60;      % seconds; Cycle time between two consecutive droplet formation cycles

zerotime = 4;           % seconds; ensureing a zero state before pulsing and before waiting for next DoD cycle

droplets = 50;          % Number of droplet on demand generation cycles 
% End of user defined variables

%Beginning of the DoD script  

for i = 1:droplets
    
    %STEP-1 : Initialization of the pump. Setting pressures of dispersed 
    % and continuous phase at equilibrium pressure values. 
    disp('Starting new droplet routine.');
    
    Chann = 1;
    PressureValue = p_c;
    mfcs_set_auto(HandleNumber,PressureValue,Chann,AlphaValue);
    
    Chann = 2;
    PressureValue = p_d;
    mfcs_set_auto(HandleNumber,PressureValue,Chann,AlphaValue);
   
    pause(zerotime); 
    
    
    %Step-2 : This is beginning of the droplet creation process where the
    %dispersed phased is pulse to push the interphase in the nozzle
    disp('Creating a droplet through pulse.');
    
    Chann = 1;
    PressureValue = p_c - deltap_c_form;
    mfcs_set_auto(HandleNumber,PressureValue,Chann,AlphaValue);
    
    Chann = 2;
    PressureValue = p_d + deltap_d_form; 
    mfcs_set_auto(HandleNumber,PressureValue,Chann,AlphaValue);
    
    pause(deltat_form);
 
    %Step-3 : Pausing to enable complete filling of the chamber by the
    %dispersed phase
    
    disp('Pausing before releasing');
    
    Chann = 1;
    PressureValue = p_c - deltap_c_form; 
    mfcs_set_auto(HandleNumber,PressureValue,Chann,AlphaValue);
    
    Chann = 2;
    PressureValue = p_d; 
    mfcs_set_auto(HandleNumber,PressureValue,Chann,AlphaValue);
  
    pause(deltat_pause); 
 
    
    %Step-4 : Pinchoff and transporting the droplet out of the device by
    %elevating the pressures of continuous and dispersed phase
    
    disp('Transporting droplet');
    Chann = 1;
    PressureValue = p_c + deltap_c_release;
    mfcs_set_auto(HandleNumber,PressureValue,Chann,AlphaValue);
    
    Chann = 2;
    PressureValue = p_d + deltap_d_release; 
    mfcs_set_auto(HandleNumber,PressureValue,Chann,AlphaValue);
    
    pause(deltat_release);
       
    %Step-5 : Zeroing
    disp('Zeroing 3');
    
    Chann = 1;
    PressureValue = p_c;
    mfcs_set_auto(HandleNumber,PressureValue,Chann,AlphaValue);
    
    Chann = 2;
    PressureValue = p_d;
    mfcs_set_auto(HandleNumber,PressureValue,Chann,AlphaValue);
    
    pause(zerotime)
    
    str=sprintf('Done with run %d', i);
    disp(str);
    
    %Step-6 : Waiting between subsequent droplet on demand generation
    % cycles 
   
    if i ~= droplets   
        str=sprintf('waiting for %d seconds until new droplet', deltat_cycle);
        disp(str);
        
        Chann = 1;
        PressureValue = p_c;
        mfcs_set_auto(HandleNumber,PressureValue,Chann,AlphaValue);
        
        Chann = 2;
        PressureValue = p_d;
        mfcs_set_auto(HandleNumber,PressureValue,Chann,AlphaValue);
        
        pause(deltat_cycle);
        
    end
    
end  %End of the droplet on demand  generation routine
 
% Last Step : Again setting the pressures of the continuous and dispersed
% phase to the equilibrium pressures
 
disp('Final zeroing');
    
Chann = 1;
PressureValue = p_c;
mfcs_set_auto(HandleNumber,PressureValue,Chann,AlphaValue);
 
Chann = 2;
PressureValue = p_d;
mfcs_set_auto(HandleNumber,PressureValue,Chann,AlphaValue);

disp('Done with everything!');

mfcs_close(HandleNumber, 'CloseLib');
fclose(fid);

